.. _qupath_ext:

QuPath extension
================

WSInfer has a QuPath extension for interactive model inference. The documentation is part of QuPath's website.
Please `see here <https://qupath.readthedocs.io/en/latest/docs/deep/wsinfer.html>`_.
